package ru.pricepulse.parsingservice.ozon_parser.service.marketplace.ozon.page;

import lombok.extern.slf4j.Slf4j;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.ui.WebDriverWait;
import ru.pricepulse.parsingservice.ozon_parser.service.marketplace.ozon.MarketplacePage;

import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import static org.openqa.selenium.support.ui.ExpectedConditions.visibilityOfAllElements;
import static org.openqa.selenium.support.ui.ExpectedConditions.visibilityOfElementLocated;

@Slf4j
public class CategoryPage implements MarketplacePage {

    private static final int PAGE_SIZE = 12;
    private static final String SEARCH_RESULTS = "div[data-widget='searchResultsV2']";

    private final By searchResults = By.cssSelector(SEARCH_RESULTS);

    private WebDriver driver;

    private WebDriverWait wait;

    public CategoryPage(WebDriver driver, WebDriverWait wait) {
        this.driver = driver;
        this.wait = wait;
    }

    public Set<String> getProductsLinks() {
        wait.until(visibilityOfElementLocated(searchResults));
        var searchResultsElement = driver.findElement(searchResults);
        wait.until(driver -> visibilityOfElementLocated(By.cssSelector(":scope > div")));
        var outerDiv = searchResultsElement.findElement(By.cssSelector(":scope > div")); // Внешний блок со списком товаров
        wait.until(driver -> visibilityOfAllElements(outerDiv.findElements(By.cssSelector(":scope > div"))));
        var innerDivs = outerDiv.findElements(By.cssSelector(":scope > div")); // Блок карточки товара
        return searchProductsLinks(innerDivs, driver);
    }

    private Set<String> searchProductsLinks(List<WebElement> innerDivs, WebDriver driver) {
        return innerDivs.stream()
            .map(div -> {
                waitVisibility(div);
                List<WebElement> linkTags = null;
                try {
                    linkTags = div.findElements(By.tagName("a"));
                } catch (Exception ignored) {}
                return linkTags != null && !linkTags.isEmpty()
                       ? linkTags.getFirst().getAttribute("href")
                       : null;
            })
            .filter(href -> href != null && !href.isEmpty())
            .collect(Collectors.toSet());
    }

    private void waitVisibility(WebElement outerElement) {
        wait.until(driver -> !outerElement.findElements(By.tagName("a")).isEmpty());
    }

    @Override
    public boolean isLoaded() {
        try {
            return driver.findElement(searchResults) != null;
        } catch (Exception e) {
            return false;
        }
    }

}
